==> react-native-rook-logger-react-native-0.2.0.tgz: package/src/hooks/useRookLogger.ts <==
import { useMachine } from '@xstate/react';
import { LoggerController } from '../controllers/LoggerController';
import type {
  ExtractionLog,
  LoggerContext,
  TransmissionLog,
} from '../types/LoggerTypes';
import type { LogBoundaryProps, LogSelector } from '../types/LogBoundaryTypes';

type LoggerProps = Partial<LoggerContext> &
  Omit<LoggerContext, 'timestamp' | 'content' | 'deviceInfo' | 'userID'>;

export const useRookLogger = () => {
  const [_, send] = useMachine(LoggerController);

  const initLogger = (props: LoggerProps): void => {
    const { clientUUID, environment, sdkInfo, userID } = props;

    send({
      type: 'init',
      payload: {
        clientUUID,
        environment,
        sdkInfo,
        userID,
      },
    });
  };

  const sendExtractionLog = (content: ExtractionLog): void => {
    send({ type: 'send', payload: content });
  };

  const sendTransmissionLog = (content: TransmissionLog): void => {
    send({ type: 'send', payload: content });
  };

  /**
   * The `logBoundary` function is a TypeScript function that wraps another function and logs the
   * success or failure of the wrapped function.
   * @param props - The `props` parameter is an object that contains the following properties:
   * @returns The function `logBoundary` returns a `Promise` that resolves to the response from the
   * `fun` function.
   */
  const logBoundary = async <T>(props: LogBoundaryProps<T>): Promise<T> => {
    const { fun, logSuccess, payload, logType, dataType } = props;

    try {
      const response = await fun(payload);

      if (logSuccess)
        sendLog({
          dataType,
          logType,
          message: { status: 'Success', description: dataType },
        });

      return response;
    } catch (error) {
      sendLog({
        dataType,
        logType,
        message: { status: 'Failure', description: `${error}` },
      });
      throw error;
    }
  };

  /**
   * The function `sendLog` sends log messages based on the log type, either extraction or
   * transmission.
   * @param {LogSelector}  - - `dataType`: The type of data being logged.
   */
  const sendLog = ({ dataType, message, logType }: LogSelector): void => {
    if (logType === 'extraction')
      sendExtractionLog({
        data_type: dataType,
        data_datetime: new Date().toISOString(),
        status: message.status,
      });
    else
      sendTransmissionLog({
        data_type: dataType,
        data_datetime: new Date().toISOString(),
        server_response: message.description,
      });
  };

  return {
    initLogger,
    sendExtractionLog,
    sendTransmissionLog,
    logBoundary,
  };
};

==> react-native-rook-logger-react-native-0.2.1.tgz: package/src/hooks/useRookLogger.ts <==
import { useMachine } from '@xstate/react';
import { LoggerController } from '../controllers/LoggerController';
import type {
  ExtractionLog,
  LoggerContext,
  TransmissionLog,
} from '../types/LoggerTypes';
import type { LogBoundaryProps, LogSelector } from '../types/LogBoundaryTypes';

type LoggerProps = Partial<LoggerContext> &
  Omit<LoggerContext, 'timestamp' | 'content' | 'deviceInfo' | 'userID'>;

export const useRookLogger = () => {
  const [_, send] = useMachine(LoggerController);

  const initLogger = (props: LoggerProps): void => {
    const { clientUUID, environment, sdkInfo, userID } = props;

    send({
      type: 'init',
      payload: {
        clientUUID,
        environment,
        sdkInfo,
        userID,
      },
    });
  };

  const sendExtractionLog = (content: ExtractionLog): void => {
    send({ type: 'send', payload: content });
  };

  const sendTransmissionLog = (content: TransmissionLog): void => {
    send({ type: 'send', payload: content });
  };

  /**
   * The `logBoundary` function is a TypeScript function that wraps another function and logs the
   * success or failure of the wrapped function.
   * @param props - The `props` parameter is an object that contains the following properties:
   * @returns The function `logBoundary` returns a `Promise` that resolves to the response from the
   * `fun` function.
   */
  const logBoundary = async <T>(props: LogBoundaryProps<T>): Promise<T> => {
    const { fun, logSuccess, payload, logType, dataType, failureReason } =
      props;

    try {
      const response = await fun(payload);

      if (logSuccess)
        sendLog({
          dataType,
          logType,
          message: { status: 'Success', description: dataType, failureReason },
        });

      return response;
    } catch (error) {
      sendLog({
        dataType,
        logType,
        message: { status: 'Failure', description: `${error}` },
      });
      throw error;
    }
  };

  /**
   * The function `sendLog` sends log messages based on the log type, either extraction or
   * transmission.
   * @param {LogSelector}  - - `dataType`: The type of data being logged.
   */
  const sendLog = ({ dataType, message, logType }: LogSelector): void => {
    if (logType === 'extraction')
      sendExtractionLog({
        data_type: dataType,
        data_datetime: new Date().toISOString(),
        status: message.status,
        failure_reason: message.failureReason,
      });
    else
      sendTransmissionLog({
        data_type: dataType,
        data_datetime: new Date().toISOString(),
        server_response: message.description,
      });
  };

  return {
    initLogger,
    sendExtractionLog,
    sendTransmissionLog,
    logBoundary,
  };
};
